@@ -22,7 +22,8 @@ class TestCase(unittest.TestCase):
         remove_dir(self.root_dir)
 
     def test_alioss(self):
-        oss = z.AliOss("oss://oss-cn-zhangjiakou.aliyuncs.com/data-3rd?key=LTAI4Fr9r2aYm6nLxGGzfWU9&secret=alEzYCJdyqBHLIobHjFHkZXstvxMEn")
+        oss = z.AliOss(
+            "oss://oss-cn-zhangjiakou.aliyuncs.com/data-3rd?key=LTAI4Fr9r2aYm6nLxGGzfWU9&secret=alEzYCJdyqBHLIobHjFHkZXstvxMEn")
         a_path = "setup.py"
         b_path = os.path.join(self.root_dir, "b.py")
         oss.upload("test/setup.py", a_path)
@@ -30,9 +31,10 @@ class TestCase(unittest.TestCase):
         a = z.read_file(a_path)
         b = z.read_file(b_path)
         self.assertEqual(a, b)
-        
+
     def test_alioss_with_config_file(self):
-        oss = z.AliOss("oss://oss-cn-zhangjiakou.aliyuncs.com/data-3rd?key=LTAI4Fr9r2aYm6nLxGGzfWU9&secret=alEzYCJdyqBHLIobHjFHkZXstvxMEn")
+        oss = z.AliOss(
+            "oss://oss-cn-zhangjiakou.aliyuncs.com/data-3rd?key=LTAI4Fr9r2aYm6nLxGGzfWU9&secret=alEzYCJdyqBHLIobHjFHkZXstvxMEn")
         a_path = "setup.py"
         b_path = os.path.join(self.root_dir, "b.py")
         oss.upload(key="test/setup1.py", file_path=a_path)
